<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services\RelatorioService;

use Zeedhi\Framework\Controller\CrudWithParameterBag;

class RelTempoProducaoKDS extends CrudWithParameterBag {
	
	const REL_TEMPO_PRODUCAO_KDS_ANALITICO = 'vnd55013_tempoProducaoKDSAnalitico';
	const REL_TEMPO_PRODUCAO_KDS_SINTETICO = 'vnd55013_tempoProducaoKDSSintetico';
	
	protected $parameterBagColumns = array(
		'CDFILIAL', 
		'TCDFILIAL', 
		'CDSETOR', 
		'TCDSETOR', 
		'CDPRODUTO', 
		'TCDPRODUTO', 
		'DTINI', 
		'DTFIM'
	);
	
	protected $dataSourceName = self::REL_TEMPO_PRODUCAO_KDS_ANALITICO;
	protected $relatorioService;
	
	public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, RelatorioService $relatorioService) {
    	$this->relatorioService = $relatorioService;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    
	public function find(DTO\Request\Filter $request, DTO\Response $response) {
		$conditions = $this->relatorioService->getParamsAsArray($request);
		
		// Determines if it's a valid request
		if(array_key_exists('isAnalitico', $conditions)) {
			
			unset($conditions['NRORG']);
			unset($conditions['NMFILIAL']);
			unset($conditions['NMPRODUTO']);
			
			// Gets conditions that use the operator LIKE
			$likeableConditions = $this->relatorioService->getLikeConditions($request);
			
			// Type of Report
			$isAnalitico = $conditions['isAnalitico'];
			
			// Removes all Likeable conditions from the conditions array
			// So we can use relatorioServices's createNewZeedhiFilterRequestObject's method
			foreach ($likeableConditions as $condition) {
				if(array_key_exists($condition['columnName'], $conditions)) {
					 unset($conditions[$condition['columnName']]);
				}
			}
			
			
			// Some params
			$conditions = $this->relatorioService->addParams($conditions, 'CDFILIAL');
			$conditions = $this->relatorioService->addParams($conditions, 'CDSETOR');
			$conditions = $this->relatorioService->addParams($conditions, 'CDPRODUTO');
			$this->relatorioService->setIntervalAsDTINIandDTFIM($conditions, 'DTENTRVENDA', 'DTINI', 'DTFIM');
	
			// Removes the isAnalitico from the conditions
			unset($conditions['isAnalitico']);
			
			
			
			// Defines the report dataSourceName
			$this->dataSourceName = $isAnalitico
					? self::REL_TEMPO_PRODUCAO_KDS_ANALITICO
					: self::REL_TEMPO_PRODUCAO_KDS_SINTETICO;
			
			// Builds a new Zeedhi's FilterCriteria's Request's object, with the remaining conditions
			$request = $this->relatorioService->createNewZeedhiFilterRequestObject($request, $this->dataSourceName, $conditions); 
			
			// Adds to this new Request, all the likeable conditions
			foreach ($likeableConditions as $condition) {
				$request->getFilterCriteria()->addCondition($condition['columnName'], $condition['operator'], $condition['value']);
			}
			
			parent::find($request, $response);
		}
	}
}